@@ -75,7 +75,7 @@ def install_service():
     return 0
 
 def uninstall_service():
-    for prog in (['update-rc.d', MODULE, 'remove', '-f'],
+    for prog in (['update-rc.d', '-f', MODULE, 'remove'],
                  ['/usr/lib/lsb/remove_initd', MODULE]):
         try:
             subprocess.call(prog)
@@ -100,6 +100,9 @@ def start_service():
 def stop_service():
     return stop_daemon()
 
+def query_service_installed():
+    return os.path.exists(INIT_PATH)
+
 def is_daemon(pid, name):
     try:
         cmdline = file('/proc/%d/cmdline' % pid, 'r').read().split('\0')
